use strict;

package ASCOPE::Article::Collection::NYTimes::LocationDB;
use base qw (Class::DBI::SQLite);

# $Id: LocationDB.pm,v 1.4 2004/09/18 22:10:49 asc Exp $

=head1 NAME

ASCOPE::Article::Collection::NYTimes::LocationDB - persistent data-store for ASCOPE::Article::Collection::NYTimes locations

=head1 SYNOPSIS

 my $nyt = ASCOPE::Article::Collection::NYTimes->new();
 $nyt->load_location_db("/path/to/sqlite.db");
 
 $nyt->add_location({name      => "Downtown Foo",
                     latitude  => 123,
                     longitude => 456, 
		     region    => "bar",
		     locality  => "foo",
		     country   => "baz"});
 
 # $loc is a ASC:A:C:NYT::LocationDB (Class::DBI) object  

 my ($loc) = $nyt->find_location({name => "Downtown Foo"});
 $loc->delete();

=head1 DESCRIPTION

Persistent data-store, using SQLite (2), for ASCOPE::Article::Collection::NYTimes
locations.

=cut

use Class::DBI::AbstractSearch;

=head1 PACKAGE METHODS

=cut

=head2 __PACKAGE__->load($path_db)

You must call this method is you plan to use this package outside
of ASCOPE::Article::Collection::NYTimes.

=cut

sub load {
    my $pkg     = shift;
    my $path_db = shift;

    eval {
	$pkg->set_db('Main', sprintf("dbi:SQLite2:dbname=%s",$path_db));
	$pkg->set_up_table("places");
	
	$pkg->columns(All => qw/name country region locality latitude longitude/);
    };

    return ($@) ? undef : $pkg;
}

=head1 OBJECT METHODS

This package inherits methods from Class::DBI and 
Class::DBI::AbstractSearch

=cut

=head2 $obj->name()

String.

=head2 $obj->latitude()

Decimal latitude.

=head2 $obj->longitude()

Decimal longitude.

=head2 $obj->locality()

String.

=head2 $obj->region()

Two letter region code.

=head2 $obj->country()

Three letter country code.

=cut

=head1 VERSION

1.0

=head1 DATE

$Date: 2004/09/18 22:10:49 $

=head1 AUTHOR

Aaron Straup Cope E<lt>ascope@cpan.orgE<gt>

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All rights reserved.

This is free software, you may use it and distribute it under
the same terms as Perl itself.

=cut

return 1;
