use strict;

package ASCOPE::Article::Collection::NYTimes::USA;
use base qw (Exporter);

# $Id: USA.pm,v 1.2 2004/09/18 21:51:49 asc Exp $

=head1 NAME

ASCOPE::Article::Collection::NYTimes::US - US specific functions for ASCOPE::Article::Collection::NYTimes

=head1 SYNOPSIS

 Ceci n'est pas une boite noire. Please use
 ASCOPE::Article::Collection::NYTimes
    
=head1 DESCRIPTION

US specific functions for ASCOPE::Article::Collection::NYTimes

=cut

use vars qw (@EXPORT);
@EXPORT    = qw(usstate_latlong
		usstate_longname
		usstate_iso
		uscity_latlong);

use WWW::Gazetteer;

my $offset = undef;

sub usstate_latlong {
    my $code = shift;

    my $lat  = undef;
    my $long = undef;

    $offset ||= tell DATA;
    seek(DATA,$offset,0);

    while (<DATA>) {
	my $ln = $_;

	if ($ln =~ /^$code/) {
	    chomp $ln;

	    ($lat,$long) = (split/,/,$ln)[2,3];
	    last;
	}
    }

    return ($lat,$long);
}

sub usstate_longname {
    my $code = shift;

    my $name = undef;

    $offset ||= tell DATA;
    seek(DATA,$offset,0);

    while (<DATA>) {
	my $ln = $_;

	if ($ln =~ /^$code/) {
	    chomp $ln;

	    $name = (split(/,/,$ln))[1];
	    last;
	}
    }
    
    return $name;
}

sub usstate_iso {
    my $state = shift;
    my $iso   = undef;

    if ($state eq "Fla") {
	$state = "Florida";
    }

    elsif ($state eq "Mo") {
	$state = "Missouri";
    }

    else {}

    #

    $offset ||= tell DATA;
    seek(DATA,$offset,0);

    while (<DATA>) {
	my $ln = $_;

	if ($ln =~ /^([A-Z][A-Z]),$state/) {
	    
	    $iso = $1;
	    last;
	}
    }
    
    return $iso;
}

sub uscity_latlong {
    my $city  = shift;
    my $state = shift;

    $state =~ s/^NYC/NY/;

    #

    my $region = &usstate_longname(uc($state));

    if (! $region) {
	# print STDERR "can't determine region for $state\n";
	return undef;
    }

    #

    my $g   = WWW::Gazetteer->new('heavensabove');
    my @loc = ();

    eval {

	# TO DO : wrap all of this up in a
	# convenient subroutine reference to
	# pass to grep 

	if ($city eq "Manhattan") {
	    @loc = grep {
		$_->{region} eq "New York";
	    } $g->find($city,"US");
	}

	elsif ($city eq "Bronx") {
	    @loc = grep {
		$_->{region} eq "New York";
	    } $g->find($city,"US");
	}

	elsif ($city eq "Brooklyn") {
	    @loc = grep {
		$_->{county} eq "Delaware";
	    } grep {
		$_->{region} eq "New York";
	    } $g->find($city,"US");
	}

	else {
	    @loc = grep {
		$_->{region} eq $region;
	    }$g->find($city, 'US');
	}

    };

    #

    if ($@) {
	warn "[$city US] $@\n";
	return undef;
    }

    if (scalar(@loc) > 1) {
	warn "multiple results for $city US\n";
	return undef;
    }

    #

    return ($loc[0]->{latitude},
	    $loc[0]->{longitude});
}

=head1 VERSION

1.0

=head1 DATE

$Date: 2004/09/18 21:51:49 $

=head1 AUTHOR

Aaron Straup Cope E<lt>ascope@cpan.orgE<gt>

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All rights reserved.

This is free software, you may use it and distribute it under
the same terms as Perl itself.

=cut

return 1;

__DATA__
AK,Alaska,61.3850,-152.2683
AL,Alabama,32.7990,-86.8073
AR,Arkansas,34.9513,-92.3809
AS,American Samoa,14.2417,-170.7197
AZ,Arizona,33.7712,-111.3877
CA,California,36.1700,-119.7462
CO,Colorado,39.0646,-105.3272
CT,Connecticut,41.5834,-72.7622
DC,District of Columbia,38.8964,-77.0262
DE,Delaware,39.3498,-75.5148
FL,Florida,27.8333,-81.7170
GA,Georgia,32.9866,-83.6487
HI,Hawaii,21.1098,-157.5311
IA,Iowa,42.0046,-93.2140
ID,Idaho,44.2394,-114.5103
IL,Illinois,40.3363,-89.0022
IN,Indiana,39.8647,-86.2604
KS,Kansas,38.5111,-96.8005
KY,Kentucky,37.6690,-84.6514
LA,Louisiana,31.1801,-91.8749
MA,Massachusetts,42.2373,-71.5314
MD,Maryland,39.0724,-76.7902
ME,Maine,44.6074,-69.3977
MI,Michigan,43.3504,-84.5603
MN,Minnesota,45.7326,-93.9196
MO,Missouri,38.4623,-92.3020
MP,Northern Mariana Islands,14.8058,145.5505
MS,Mississippi,32.7673,-89.6812
MT,Montana,46.9048,-110.3261
NC,North Carolina,35.6411,-79.8431
ND,North Dakota,47.5362,-99.7930
NE,Nebraska,41.1289,-98.2883
NH,New Hampshire,43.4108,-71.5653
NJ,New Jersey,40.3140,-74.5089
NM,New Mexico,34.8375,-106.2371
NV,Nevada,38.4199,-117.1219
NY,New York,42.1497,-74.9384
OH,Ohio,40.3736,-82.7755
OK,Oklahoma,35.5376,-96.9247
OR,Oregon,44.5672,-122.1269
PA,Pennsylvania,40.5773,-77.2640
PR,Puerto Rico,18.2766,-66.3350
RI,Rhode Island,41.6772,-71.5101
SC,South Carolina,33.8191,-80.9066
SD,South Dakota,44.2853,-99.4632
TN,Tennessee,35.7449,-86.7489
TX,Texas,31.1060,-97.6475
UT,Utah,40.1135,-111.8535
VA,Virginia,37.7680,-78.2057
VI,Virgin Islands of the U.S.,18.0001,-64.8199
VT,Vermont,44.0407,-72.7093
WA,Washington,47.3917,-121.5708
WI,Wisconsin,44.2563,-89.6385
WV,West Virginia,38.4680,-80.9696
WY,Wyoming,42.7475,-107.2085
